/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 03401
 |         SUBSTANCE ABUSE TREATMENT COST ALLOCATION AND ANALYSIS
 |                  TEMPLATE (SATCAAT) STUDY, 1992-1994
 |               (DATASET 0002: SDU COST DATA -- ALL SDUS)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\03401-0002-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE sdunum    -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE provider  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE sdufocus  -8='(-8) INAPPLICABLE' 1='(1) AFTERCARE' 2='(2) CHILDREN' 3='(3) DETOX'
                  4='(4) HIV' 5='(5) OUTPATIENT' 6='(6) RESIDENTIAL' 7='(7) WOMEN' ;
  VALUE sdutype   -9='(-9) BLANK' -8='(-8) INAPPLICABLE'
                  1='(1) TRANSITIONAL LIVING AFTERCARE' 2='(2) AFTERCARE-WOMEN ONLY'
                  3='(3) OUTPATIENT-AFTERCARE (ADOLESCENT)'
                  4='(4) OUTPATIENT-AFTERCARE (ADULT)'
                  5='(5) RESIDENTIAL PPW-CHILDREN ONLY'
                  6='(6) RESIDENTIAL WOMEN & CHILDREN-CHILDREN ONLY'
                  7='(7) RESIDENTIAL-ADOLESCENT'
                  8='(8) RESIDENTIAL LONG TERM PPW-CHILDREN ONLY'
                  9='(9) RESIDENTIAL SHORT TERM PPW-CHILDREN ONLY'
                  10='(10) RESIDENTIAL-DETOXIFICATION (ADULT)'
                  11='(11) HIV/AIDS OUTREACH' 12='(12) HIV-AIDS OUTREACH-INTENSIVE'
                  13='(13) HIV OUTPATIENT PREVENTION AND COUNSELING'
                  14='(14) HIV OUTREACH AND PRETREATMENT'
                  15='(15) INTENSIVE OUTPATIENT' 16='(16) METHADONE' 17='(17) OUTPATIENT'
                  18='(18) PARTIAL HOSPITAL' 19='(19) OUTPATIENT-ADOLESCENT'
                  20='(20) OUTPATIENT-ADULT' 21='(21) OUTPATIENT-WOMEN'
                  22='(22) RESIDENTIAL-ADULT' 23='(23) RESIDENTIAL PPW-WOMEN ONLY'
                  24='(24) RESIDENTIAL WOMEN & CHILDREN-WOMEN ONLY'
                  25='(25) CENTRAL INTAKE PPW-WOMEN'
                  26='(26) RESIDENTIAL LONG TERM PPW-WOMEN ONLY'
                  27='(27) RESIDENTIAL SHORT TERM PPW-WOMEN ONLY' ;
  VALUE fyend     -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE numclnt   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totcost   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totaft    -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totcnet   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totch     -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totcled   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE tottran   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE tothiv    -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE tothm     -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE tothous   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totiass   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totmds    -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totmes    -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totmhgc   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totmhic   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totpevl   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totpse    -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totrmgt   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totsagc   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totsaic   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE totsted   -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unaft1ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unaft3ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unaft7ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unaft10f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unaft12f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet4f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet7f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet9f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet0f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet2f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncnet5f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unch5fff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uncled7f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE untran1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE untran2f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE untran3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE untran7f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE untran8f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhiv7ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhiv22f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhiv23f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhiv28f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhm16ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhm18ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhm19ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unhous1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uniass2f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uniass3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmds4ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmds7ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmds24f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmds25f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmds26f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmds31f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmes15f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmes16f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmes31f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmhgc8f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmhgc1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmhic8f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unmhic1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unpev7ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unpse13f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unpse14f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unpse15f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unpse16f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unpse31f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unrmgt4f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unrmgt7f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unrmgt3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsagc8f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsagc1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsagc2f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsagc3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsaic8f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsaic1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsaic2f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsaic3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsted7f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsted1f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsted0f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE unsted3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE ucaft1ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucaft3ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucaft7ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucaft10f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucaft12f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet4f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet7f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet9f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet0f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet2f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet3f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccnet5f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucch5fff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uccled7f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uctran7f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uctran8f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uctran1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uctran2f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uctran3f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uchiv22f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uchiv23f  -9.0='(-9.0) BLANK' -8.0='(-8.0) INAPPLICABLE' ;
  VALUE uchiv28f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uchiv7ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uchm16ff  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE uchm18ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uchm19ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uchous1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uciass2f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE uciass3f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmds4ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmds7ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmds24f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmds25f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmds26f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmds31f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmes15f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmes16f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmes31f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmhgc1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucmhic1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucpev7ff  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucpse13f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucpse14f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucpse15f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucpse16f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucpse31f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucrmgt4f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucrmgt7f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucrmgt3f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsagc8f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsagc1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsagc2f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsagc3f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsaic8f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsaic1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsaic2f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsaic3f  -9='(-9) BLANK' -8='(-8) INAPPLICABLE' ;
  VALUE ucsted7f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsted1f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsted0f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE ucsted3f  -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE cstprcl   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgaft    -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgcnet   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgch     -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgcled   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgtran   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avghiv    -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avghm     -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avghous   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgiass   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgmds    -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgmes    -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgmhgc   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgmhic   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgpevl   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgpse    -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgrmgt   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgsagc   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgsaic   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
  VALUE avgsted   -9.00='(-9.00) BLANK' -8.00='(-8.00) INAPPLICABLE' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=837;
INPUT
        CASEID 1-3              SDUNUM 4-7              PROVIDER 8-9
        SDUFOCUS 10             SDUTYPE 11-12           FYEND 13-14
        NUMCLNT 15-17           TOTCOST 18-24           TOTAFT 25-29
        TOTCNET 30-35           TOTCH 36-41             TOTCLED 42-46
        TOTTRAN 47-52           TOTHIV 53-57            TOTHM 58-63
        TOTHOUS 64-69           TOTIASS 70-74           TOTMDS 75-80
        TOTMES 81-86            TOTMHGC 87-91           TOTMHIC 92-96
        TOTPEVL 97-102          TOTPSE 103-108          TOTRMGT 109-114
        TOTSAGC 115-120         TOTSAIC 121-126         TOTSTED 127-131
        UNAFT1 132-135          UNAFT3 136-137          UNAFT7 138-139
        UNAFT10 140-143         UNAFT12 144-145         UNCNET4 146-147
        UNCNET7 148-149         UNCNET9 150-153         UNCNET10 154-157
        UNCNET16 158-159        UNCNET20 160-161        UNCNET21 162-165
        UNCNET31 166-167        UNCH5 168-170           UNCLED7 171-173
        UNTRAN16 174-175        UNTRAN29 176-177        UNTRAN31 178-179
        UNTRAN7 180-183         UNTRAN8 184-187         UNHIV7 188-190
        UNHIV22 191-193         UNHIV23 194-195         UNHIV28 196-197
        UNHM16 198-199          UNHM18 200-204          UNHM19 205-208
        UNHOUS18 209-213        UNIASS2 214-216         UNIASS31 217-218
        UNMDS4 219-220          UNMDS7 221-224          UNMDS24 225-227
        UNMDS25 228-230         UNMDS26 231-232         UNMDS31 233-234
        UNMES15 235-237         UNMES16 238-239         UNMES31 240-241
        UNMHGC8 242-243         UNMHGC11 244-246        UNMHIC8 247-248
        UNMHIC11 249-252        UNPEV7 253-255          UNPSE13 256-258
        UNPSE14 259-261         UNPSE15 262-263         UNPSE16 264-265
        UNPSE31 266-267         UNRMGT4 268-270         UNRMGT7 271-272
        UNRMGT31 273-274        UNSAGC8 275-278         UNSAGC11 279-282
        UNSAGC27 283-286        UNSAGC31 287-290        UNSAIC8 291-294
        UNSAIC11 295-299        UNSAIC27 300-303        UNSAIC31 304-308
        UNSTED7 309-311         UNSTED16 312-314        UNSTED17 315-317
        UNSTED31 318-319        UCAFT1 320-325 .2       UCAFT3 326-332 .2
        UCAFT7 333-338 .2       UCAFT10 339-345 .2      UCAFT12 346-352 .2
        UCCNET4 353-358 .2      UCCNET7 359-365 .2      UCCNET9 366-370 .2
        UCCNET10 371-377 .2     UCCNET16 378-383 .2     UCCNET20 384-390 .2
        UCCNET21 391-395 .2     UCCNET31 396-402 .2     UCCH5 403-410 .2
        UCCLED7 411-417 .2      UCTRAN7 418-424 .2      UCTRAN8 425-431 .2
        UCTRAN16 432-437 .2     UCTRAN29 438-444 .2     UCTRAN31 445-451 .2
        UCHIV22 452-456 .2      UCHIV23 457-461 .1      UCHIV28 462-466 .2
        UCHIV7 467-472 .2       UCHM16 473-474          UCHM18 475-480 .2
        UCHM19 481-485 .2       UCHOUS18 486-491 .2     UCIASS2 492-498 .2
        UCIASS31 499-503 .2     UCMDS4 504-510 .2       UCMDS7 511-517 .2
        UCMDS24 518-522 .2      UCMDS25 523-527 .2      UCMDS26 528-533 .2
        UCMDS31 534-540 .2      UCMES15 541-546 .2      UCMES16 547-552 .2
        UCMES31 553-558 .2      UCMHGC11 559-563 .2     UCMHIC11 564-569 .2
        UCPEV7 570-576 .2       UCPSE13 577-583 .2      UCPSE14 584-590 .2
        UCPSE15 591-595 .2      UCPSE16 596-601 .2      UCPSE31 602-607 .2
        UCRMGT4 608-615 .2      UCRMGT7 616-622 .2      UCRMGT31 623-629 .2
        UCSAGC8 630-635 .2      UCSAGC11 636-641 .2     UCSAGC27 642-646 .2
        UCSAGC31 647-651 .2     UCSAIC8 652-657 .2      UCSAIC11 658-663 .2
        UCSAIC27 664-668 .2     UCSAIC31 669-670        UCSTED7 671-677 .2
        UCSTED16 678-683 .2     UCSTED17 684-690 .2     UCSTED31 691-696 .2
        CSTPRCL 697-704 .2      AVGAFT 705-711 .2       AVGCNET 712-718 .2
        AVGCH 719-726 .2        AVGCLED 727-733 .2      AVGTRAN 734-740 .2
        AVGHIV 741-746 .2       AVGHM 747-753 .2        AVGHOUS 754-761 .2
        AVGIASS 762-768 .2      AVGMDS 769-775 .2       AVGMES 776-781 .2
        AVGMHGC 782-787 .2      AVGMHIC 788-794 .2      AVGPEVL 795-801 .2
        AVGPSE 802-808 .2       AVGRMGT 809-816 .2      AVGSAGC 817-823 .2
        AVGSAIC 824-830 .2      AVGSTED 831-837 .2      ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   SDUNUM  = 'SERVICE DELIVER UNIT IDENTIFICATION NUMBER'
   PROVIDER= 'PROVIDER IDENTIFICATION NUMBER'
   SDUFOCUS= 'SERVICE DELIVERY UNIT FOCUS'
   SDUTYPE = 'SERVICE DELIVERY UNIT TYPE'
   FYEND   = 'FISCAL YEAR ENDING'
   NUMCLNT = 'SDU NUMBER OF CLIENTS'
   TOTCOST = 'TOTAL SDU COST'
   TOTAFT  = 'AFTERCARE SVC-TOTAL SDU COST'
   TOTCNET = 'CASE MGT/NETWRK SVC-TOTAL SDU COST'
   TOTCH   = 'CHILD CARE SVC-TOTAL SDU COST'
   TOTCLED = 'CLIENT EDUC SVC-TOTAL SDU COST'
   TOTTRAN = 'CLIENT TRANSPORT SVC-TOTAL SDU COST'
   TOTHIV  = 'HIV TEST & COUNSEL SVC-TOTAL SDU COST'
   TOTHM   = 'HOUSING & MEAL SVC-TOTAL SDU COST'
   TOTHOUS = 'HOUSING SVC-TOTAL SDU COST'
   TOTIASS = 'INITIAL ASSESSMT SVC-TOTAL SDU COST'
   TOTMDS  = 'MED & DIAG SVC-TOTAL SDU COST'
   TOTMES  = 'MEDICAL EXAM SVC-TOTAL SDU COST'
   TOTMHGC = 'MH GROUP COUNSEL SVC-TOTAL SDU COST'
   TOTMHIC = 'MH INDIV COUNSEL SVC-TOTAL SDU COST'
   TOTPEVL = 'PROJECT EVAL SVC-TOTAL SDU COST'
   TOTPSE  = 'PSYCHOSOCIAL EVAL SVC-TOTAL SDU COST'
   TOTRMGT = 'RECORDS MGT SVC-TOTAL SDU COST'
   TOTSAGC = 'SA GROUP COUNSEL SVC-TOTAL SDU COST'
   TOTSAIC = 'SA INDIV COUNSEL SVC-TOTAL SDU COST'
   TOTSTED = 'STAFF EDUC SVC-TOTAL SDU COST'
   UNAFT1  = 'AFTERCARE SVC-TOTAL A/CC CONTACT HRS'
   UNAFT3  = 'AFTERCARE SVC-TOTAL CASES'
   UNAFT7  = 'AFTERCARE SVC-TOTAL CLIENTS REC THIS SVC'
   UNAFT10 = 'AFTERCARE SVC-TOTAL CONTACTS'
   UNAFT12 = 'AFTERCARE SVC-TOTAL DISCHARGES'
   UNCNET4 = 'CASE MGT/NETWRK SVC-TOTAL CASES REC THIS SVC'
   UNCNET7 = 'CASE MGT/NETWRK SVC-TOTAL CLIENTS REC THIS SVC'
   UNCNET9 = 'CASE MGT/NETWRK SVC-TOTAL CONTACT HOURS'
   UNCNET10= 'CASE MGT/NETWRK SVC-TOTAL CONTACTS'
   UNCNET16= 'CASE MGT/NETWRK SVC-TOTAL HOURS'
   UNCNET20= 'CASE MGT/NETWRK SVC-TOTAL NETWORKING CASES'
   UNCNET21= 'CASE MGT/NETWRK SVC-TOTAL NETWORKING HOURS'
   UNCNET31= 'CASE MGT/NETWRK SVC-TOTAL UNIT NOT SPECIFIED'
   UNCH5   = 'CHILD CARE SVC-TOTAL CHILDREN'
   UNCLED7 = 'CLIENT EDUC SVC-TOTAL CLIENTS REC THIS SVC'
   UNTRAN16= 'CLIENT TRANSPORT SVC-TOTAL HOURS'
   UNTRAN29= 'CLIENT TRANSPORT SVC-TOTAL TRIPS/CLIENTS'
   UNTRAN31= 'CLIENT TRANSPORT SVC-TOTAL UNIT NOT SPECIFIED'
   UNTRAN7 = 'CLIENT TRANSPORT SVC-TOTAL CLIENTS REC THIS SVC'
   UNTRAN8 = 'CLIENT TRANSPORT SVC-TOTAL CONSULTING HOURS'
   UNHIV7  = 'HIV TEST & COUNSEL SVC-TOTAL CLIENTS REC THIS SVC'
   UNHIV22 = 'HIV TEST & COUNSEL SVC-TOTAL REFERRALS'
   UNHIV23 = 'HIV TEST & COUNSEL SVC-TOTAL RISK ASSESSMENTS'
   UNHIV28 = 'HIV TEST & COUNSEL SVC-TOTAL TESTS/CLIENTS'
   UNHM16  = 'HOUSING & MEAL SVC-TOTAL HOURS'
   UNHM18  = 'HOUSING & MEAL SVC-TOTAL INPATIENT DAYS'
   UNHM19  = 'HOUSING & MEAL SVC-TOTAL MEALS'
   UNHOUS18= 'HOUSING SVC-TOTAL INPATIENT DAYS'
   UNIASS2 = 'INITIAL ASSESSMT SVC-TOTAL ASSESSMENTS'
   UNIASS31= 'INITIAL ASSESSMT SVC-TOTAL UNIT NOT SPECIFIED'
   UNMDS4  = 'MED & DIAG SVC-TOTAL CASES REC THIS SVC'
   UNMDS7  = 'MED & DIAG SVC-TOTAL CLIENTS REC THIS SVC'
   UNMDS24 = 'MED & DIAG SVC-TOTAL SERVICES'
   UNMDS25 = 'MED & DIAG SVC-TOTAL SERVICES HOURS'
   UNMDS26 = 'MED & DIAG SVC-TOTAL SERVICES/CLIENTS'
   UNMDS31 = 'MED & DIAG SVC-TOTAL UNIT NOT SPECIFIED'
   UNMES15 = 'MEDICAL EXAM SVC-TOTAL EXAMS'
   UNMES16 = 'MEDICAL EXAM SVC-TOTAL HOURS'
   UNMES31 = 'MEDICAL EXAM SVC-TOTAL UNIT NOT SPECIFIED'
   UNMHGC8 = 'MH GROUP COUNSEL SVC-TOTAL CONSULTING HOURS'
   UNMHGC11= 'MH GROUP COUNSEL SVC-TOTAL COUNSELING HRS'
   UNMHIC8 = 'MH INDIV COUNSEL SVC-TOTAL CONSULTING HOURS'
   UNMHIC11= 'MH INDIV COUNSEL SVC-TOTAL COUNSELING HRS'
   UNPEV7  = 'PROJECT EVAL SVC-TOTAL UNITS (W/CLIENTS AS UNITS)'
   UNPSE13 = 'PSYCHOSOCIAL EVAL SVC-TOTAL EVALUATION HOURS'
   UNPSE14 = 'PSYCHOSOCIAL EVAL SVC-TOTAL EVALUATIONS'
   UNPSE15 = 'PSYCHOSOCIAL EVAL SVC-TOTAL EXAMS'
   UNPSE16 = 'PSYCHOSOCIAL EVAL SVC-TOTAL HOURS'
   UNPSE31 = 'PSYCHOSOCIAL EVAL SVC-TOTAL UNIT NOT SPECIFIED'
   UNRMGT4 = 'RECORDS MGT SVC-TOTAL CASES'
   UNRMGT7 = 'RECORDS MGT SVC-TOTAL UNITS (W/CLIENTS AS UNITS)'
   UNRMGT31= 'RECORDS MGT SVC-TOTAL UNIT NOT SPECIFIED'
   UNSAGC8 = 'SA GROUP COUNSEL SVC-TOTAL CONSULTING HOURS'
   UNSAGC11= 'SA GROUP COUNSEL SVC-TOTAL COUNSELING HRS'
   UNSAGC27= 'SA GROUP COUNSEL SVC-TOTAL STAFF COUNSELING HOURS'
   UNSAGC31= 'SA GROUP COUNSEL SVC-TOTAL UNIT NOT SPECIFIED'
   UNSAIC8 = 'SA INDIV COUNSEL SVC-TOTAL CONSULTING HOURS'
   UNSAIC11= 'SA INDIV COUNSEL SVC-TOTAL COUNSELING HRS'
   UNSAIC27= 'SA INDIV COUNSEL SVC-TOTAL STAFF COUNSELING HOURS'
   UNSAIC31= 'SA INDIV COUNSEL SVC-TOTAL UNIT NOT SPECIFIED'
   UNSTED7 = 'STAFF EDUC SVC-TOTAL UNITS (W/CLIENTS AS UNITS)'
   UNSTED16= 'STAFF EDUC SVC-TOTAL HOURS'
   UNSTED17= 'STAFF EDUC SVC-TOTAL HOURS/CLIENTS'
   UNSTED31= 'STAFF EDUC SVC-TOTAL UNIT NOT SPECIFIED'
   UCAFT1  = 'AFTERCARE SVC-COST PER A/CC CONTACT HR'
   UCAFT3  = 'AFTERCARE SVC-COST PER CASE'
   UCAFT7  = 'AFTERCARE SVC-COST PER CLIENT REC THIS SVC'
   UCAFT10 = 'AFTERCARE SVC-COST PER CONTACT'
   UCAFT12 = 'AFTERCARE SVC-COST PER DISCHARGE'
   UCCNET4 = 'CASE MGT/NETWRK SVC-COST PER CASE REC THIS SVC'
   UCCNET7 = 'CASE MGT/NETWRK SVC-COST PER CLIENT REC THIS SVC'
   UCCNET9 = 'CASE MGT/NETWRK SVC-COST PER CONTACT HOUR'
   UCCNET10= 'CASE MGT/NETWRK SVC-COST PER CONTACT'
   UCCNET16= 'CASE MGT/NETWRK SVC-COST PER HOUR'
   UCCNET20= 'CASE MGT/NETWRK SVC-COST PER NETWORKING CASE'
   UCCNET21= 'CASE MGT/NETWRK SVC-COST PER NETWORKING HOUR'
   UCCNET31= 'CASE MGT/NETWRK SVC-COST PER UNIT NOT SPECIFIED'
   UCCH5   = 'CHILD CARE SVC-COST PER CHILD'
   UCCLED7 = 'CLIENT EDUC SVC-COST PER CLIENT REC THIS SVC'
   UCTRAN7 = 'CLIENT TRANSPORT SVC-COST PER CLIENT REC THIS SVC'
   UCTRAN8 = 'CLIENT TRANSPORT SVC-COST PER CONSULTING HOUR'
   UCTRAN16= 'CLIENT TRANSPORT SVC-COST PER HOUR'
   UCTRAN29= 'CLIENT TRANSPORT SVC-COST PER TRIP/CLIENT'
   UCTRAN31= 'CLIENT TRANSPORT SVC-COST PER UNIT NOT SPECIFIED'
   UCHIV22 = 'HIV TEST & COUNSEL SVC-COST PER REFERRAL'
   UCHIV23 = 'HIV TEST & COUNSEL SVC-COST PER RISK ASSESSMENT'
   UCHIV28 = 'HIV TEST & COUNSEL SVC-COST PER TEST/CLIENT'
   UCHIV7  = 'HIV TEST & COUNSEL SVC-COST PER CLIENT REC THIS SVC'
   UCHM16  = 'HOUSING & MEAL SVC-COST PER HOUR'
   UCHM18  = 'HOUSING & MEAL SVC-COST PER INPATIENT DAY'
   UCHM19  = 'HOUSING & MEAL SVC-COST PER MEAL'
   UCHOUS18= 'HOUSING SVC-COST PER INPATIENT DAY'
   UCIASS2 = 'INITIAL ASSESSMT SVC-COST PER ASSESSMENT'
   UCIASS31= 'INITIAL ASSESSMT SVC-COST PER UNIT NOT SPECIFIED'
   UCMDS4  = 'MED & DIAG SVC-COST PER CASE REC THIS SVC'
   UCMDS7  = 'MED & DIAG SVC-COST PER CLIENT REC THIS SVC'
   UCMDS24 = 'MED & DIAG SVC-COST PER SERVICE'
   UCMDS25 = 'MED & DIAG SVC-COST PER SERVICE HOUR'
   UCMDS26 = 'MED & DIAG SVC-COST PER SERVICE/CLIENT'
   UCMDS31 = 'MED & DIAG SVC-COST PER UNIT NOT SPECIFIED'
   UCMES15 = 'MEDICAL EXAM SVC-COST PER EXAM'
   UCMES16 = 'MEDICAL EXAM SVC-COST PER HOUR'
   UCMES31 = 'MEDICAL EXAM SVC-COST PER UNIT NOT SPECIFIED'
   UCMHGC11= 'MH GROUP COUNSEL SVC-COST PER COUNSELING HR'
   UCMHIC11= 'MH INDIV COUNSEL SVC-COST PER COUNSELING HR'
   UCPEV7  = 'PROJECT EVAL SVC-COST PER UNIT (W/CLIENTS AS UNITS)'
   UCPSE13 = 'PSYCHOSOCIAL EVAL SVC-COST PER EVALUATION HOUR'
   UCPSE14 = 'PSYCHOSOCIAL EVAL SVC-COST PER EVALUATION'
   UCPSE15 = 'PSYCHOSOCIAL EVAL SVC-COST PER EXAM'
   UCPSE16 = 'PSYCHOSOCIAL EVAL SVC-COST PER HOUR'
   UCPSE31 = 'PSYCHOSOCIAL EVAL SVC-COST PER UNIT NOT SPECIFIED'
   UCRMGT4 = 'RECORDS MGT SVC-COST PER CASE'
   UCRMGT7 = 'RECORDS MGT SVC-COST PER UNIT (W/CLIENTS AS UNITS)'
   UCRMGT31= 'RECORDS MGT SVC-COST PER UNIT NOT SPECIFIED'
   UCSAGC8 = 'SA GROUP COUNSEL SVC-COST PER CONSULTING HOUR'
   UCSAGC11= 'SA GROUP COUNSEL SVC-COST PER COUNSELING HR'
   UCSAGC27= 'SA GROUP COUNSEL SVC-COST PER STAFF COUNSELING HOUR'
   UCSAGC31= 'SA GROUP COUNSEL SVC-COST PER UNIT NOT SPECIFIED'
   UCSAIC8 = 'SA INDIV COUNSEL SVC-COST PER CONSULTING HOUR'
   UCSAIC11= 'SA INDIV COUNSEL SVC-COST PER COUNSELING HR'
   UCSAIC27= 'SA INDIV COUNSEL SVC-COST PER STAFF COUNSELING HOUR'
   UCSAIC31= 'SA INDIV COUNSEL SVC-COST PER UNIT NOT SPECIFIED'
   UCSTED7 = 'STAFF EDUC SVC-COST PER UNIT (W/CLIENTS AS UNITS)'
   UCSTED16= 'STAFF EDUC SVC-COST PER HOUR'
   UCSTED17= 'STAFF EDUC SVC-COST PER HOUR/CLIENT'
   UCSTED31= 'STAFF EDUC SVC-COST PER UNIT NOT SPECIFIED'
   CSTPRCL = 'OVERALL SDU COST PER CLIENT'
   AVGAFT  = 'AFTERCARE SVC-AVG COST PER CLIENT'
   AVGCNET = 'CASE MGT/NETWRK SVC-AVG COST PER CLIENT'
   AVGCH   = 'CHILD CARE SVC-AVG COST PER CLIENT'
   AVGCLED = 'CLIENT EDUC SVC-AVG COST PER CLIENT'
   AVGTRAN = 'CLIENT TRANSPORT SVC-AVG COST PER CLIENT'
   AVGHIV  = 'HIV TEST & COUNSEL SVC-AVG COST PER CLIENT'
   AVGHM   = 'HOUSING & MEAL SVC-AVG COST PER CLIENT'
   AVGHOUS = 'HOUSING SVC-AVG COST PER CLIENT'
   AVGIASS = 'INITIAL ASSESSMT SVC-AVG COST PER CLIENT'
   AVGMDS  = 'MED & DIAG SVC-AVG COST PER CLIENT'
   AVGMES  = 'MEDICAL EXAM SVC-AVG COST PER CLIENT'
   AVGMHGC = 'MH GROUP COUNSEL SVC-AVG COST PER CLIENT'
   AVGMHIC = 'MH INDIV COUNSEL SVC-AVG COST PER CLIENT'
   AVGPEVL = 'PROJECT EVAL SVC-AVG COST PER CLIENT'
   AVGPSE  = 'PSYCHOSOCIAL EVAL SVC-AVG COST PER CLIENT'
   AVGRMGT = 'RECORDS MGT SVC-AVG COST PER CLIENT'
   AVGSAGC = 'SA GROUP COUNSEL SVC-AVG COST PER CLIENT'
   AVGSAIC = 'SA INDIV COUNSEL SVC-AVG COST PER CLIENT'
   AVGSTED = 'STAFF EDUC SVC-AVG COST PER CLIENT'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CASEID <= -1) THEN CASEID = .;
   IF (SDUNUM <= -1) THEN SDUNUM = .;
   IF (PROVIDER <= -1) THEN PROVIDER = .;
   IF (SDUFOCUS <= -1) THEN SDUFOCUS = .;
   IF (SDUTYPE <= -1) THEN SDUTYPE = .;
   IF (FYEND <= -1) THEN FYEND = .;
   IF (NUMCLNT <= -1) THEN NUMCLNT = .;
   IF (TOTCOST <= -1) THEN TOTCOST = .;
   IF (TOTAFT <= -1) THEN TOTAFT = .;
   IF (TOTCNET <= -1) THEN TOTCNET = .;
   IF (TOTCH <= -1) THEN TOTCH = .;
   IF (TOTCLED <= -1) THEN TOTCLED = .;
   IF (TOTTRAN <= -1) THEN TOTTRAN = .;
   IF (TOTHIV <= -1) THEN TOTHIV = .;
   IF (TOTHM <= -1) THEN TOTHM = .;
   IF (TOTHOUS <= -1) THEN TOTHOUS = .;
   IF (TOTIASS <= -1) THEN TOTIASS = .;
   IF (TOTMDS <= -1) THEN TOTMDS = .;
   IF (TOTMES <= -1) THEN TOTMES = .;
   IF (TOTMHGC <= -1) THEN TOTMHGC = .;
   IF (TOTMHIC <= -1) THEN TOTMHIC = .;
   IF (TOTPEVL <= -1) THEN TOTPEVL = .;
   IF (TOTPSE <= -1) THEN TOTPSE = .;
   IF (TOTRMGT <= -1) THEN TOTRMGT = .;
   IF (TOTSAGC <= -1) THEN TOTSAGC = .;
   IF (TOTSAIC <= -1) THEN TOTSAIC = .;
   IF (TOTSTED <= -1) THEN TOTSTED = .;
   IF (UNAFT1 <= -1) THEN UNAFT1 = .;
   IF (UNAFT3 <= -1) THEN UNAFT3 = .;
   IF (UNAFT7 <= -1) THEN UNAFT7 = .;
   IF (UNAFT10 <= -1) THEN UNAFT10 = .;
   IF (UNAFT12 <= -1) THEN UNAFT12 = .;
   IF (UNCNET4 <= -1) THEN UNCNET4 = .;
   IF (UNCNET7 <= -1) THEN UNCNET7 = .;
   IF (UNCNET9 <= -1) THEN UNCNET9 = .;
   IF (UNCNET10 <= -1) THEN UNCNET10 = .;
   IF (UNCNET16 <= -1) THEN UNCNET16 = .;
   IF (UNCNET20 <= -1) THEN UNCNET20 = .;
   IF (UNCNET21 <= -1) THEN UNCNET21 = .;
   IF (UNCNET31 <= -1) THEN UNCNET31 = .;
   IF (UNCH5 <= -1) THEN UNCH5 = .;
   IF (UNCLED7 <= -1) THEN UNCLED7 = .;
   IF (UNTRAN16 <= -1) THEN UNTRAN16 = .;
   IF (UNTRAN29 <= -1) THEN UNTRAN29 = .;
   IF (UNTRAN31 <= -1) THEN UNTRAN31 = .;
   IF (UNTRAN7 <= -1) THEN UNTRAN7 = .;
   IF (UNTRAN8 <= -1) THEN UNTRAN8 = .;
   IF (UNHIV7 <= -1) THEN UNHIV7 = .;
   IF (UNHIV22 <= -1) THEN UNHIV22 = .;
   IF (UNHIV23 <= -1) THEN UNHIV23 = .;
   IF (UNHIV28 <= -1) THEN UNHIV28 = .;
   IF (UNHM16 <= -1) THEN UNHM16 = .;
   IF (UNHM18 <= -1) THEN UNHM18 = .;
   IF (UNHM19 <= -1) THEN UNHM19 = .;
   IF (UNHOUS18 <= -1) THEN UNHOUS18 = .;
   IF (UNIASS2 <= -1) THEN UNIASS2 = .;
   IF (UNIASS31 <= -1) THEN UNIASS31 = .;
   IF (UNMDS4 <= -1) THEN UNMDS4 = .;
   IF (UNMDS7 <= -1) THEN UNMDS7 = .;
   IF (UNMDS24 <= -1) THEN UNMDS24 = .;
   IF (UNMDS25 <= -1) THEN UNMDS25 = .;
   IF (UNMDS26 <= -1) THEN UNMDS26 = .;
   IF (UNMDS31 <= -1) THEN UNMDS31 = .;
   IF (UNMES15 <= -1) THEN UNMES15 = .;
   IF (UNMES16 <= -1) THEN UNMES16 = .;
   IF (UNMES31 <= -1) THEN UNMES31 = .;
   IF (UNMHGC8 <= -1) THEN UNMHGC8 = .;
   IF (UNMHGC11 <= -1) THEN UNMHGC11 = .;
   IF (UNMHIC8 <= -1) THEN UNMHIC8 = .;
   IF (UNMHIC11 <= -1) THEN UNMHIC11 = .;
   IF (UNPEV7 <= -1) THEN UNPEV7 = .;
   IF (UNPSE13 <= -1) THEN UNPSE13 = .;
   IF (UNPSE14 <= -1) THEN UNPSE14 = .;
   IF (UNPSE15 <= -1) THEN UNPSE15 = .;
   IF (UNPSE16 <= -1) THEN UNPSE16 = .;
   IF (UNPSE31 <= -1) THEN UNPSE31 = .;
   IF (UNRMGT4 <= -1) THEN UNRMGT4 = .;
   IF (UNRMGT7 <= -1) THEN UNRMGT7 = .;
   IF (UNRMGT31 <= -1) THEN UNRMGT31 = .;
   IF (UNSAGC8 <= -1) THEN UNSAGC8 = .;
   IF (UNSAGC11 <= -1) THEN UNSAGC11 = .;
   IF (UNSAGC27 <= -1) THEN UNSAGC27 = .;
   IF (UNSAGC31 <= -1) THEN UNSAGC31 = .;
   IF (UNSAIC8 <= -1) THEN UNSAIC8 = .;
   IF (UNSAIC11 <= -1) THEN UNSAIC11 = .;
   IF (UNSAIC27 <= -1) THEN UNSAIC27 = .;
   IF (UNSAIC31 <= -1) THEN UNSAIC31 = .;
   IF (UNSTED7 <= -1) THEN UNSTED7 = .;
   IF (UNSTED16 <= -1) THEN UNSTED16 = .;
   IF (UNSTED17 <= -1) THEN UNSTED17 = .;
   IF (UNSTED31 <= -1) THEN UNSTED31 = .;
   IF (UCAFT1 <= -1.00) THEN UCAFT1 = .;
   IF (UCAFT3 <= -1.00) THEN UCAFT3 = .;
   IF (UCAFT7 <= -1.00) THEN UCAFT7 = .;
   IF (UCAFT10 <= -1.00) THEN UCAFT10 = .;
   IF (UCAFT12 <= -1.00) THEN UCAFT12 = .;
   IF (UCCNET4 <= -1.00) THEN UCCNET4 = .;
   IF (UCCNET7 <= -1.00) THEN UCCNET7 = .;
   IF (UCCNET9 <= -1.00) THEN UCCNET9 = .;
   IF (UCCNET10 <= -1.00) THEN UCCNET10 = .;
   IF (UCCNET16 <= -1.00) THEN UCCNET16 = .;
   IF (UCCNET20 <= -1.00) THEN UCCNET20 = .;
   IF (UCCNET21 <= -1.00) THEN UCCNET21 = .;
   IF (UCCNET31 <= -1.00) THEN UCCNET31 = .;
   IF (UCCH5 <= -1.00) THEN UCCH5 = .;
   IF (UCCLED7 <= -1.00) THEN UCCLED7 = .;
   IF (UCTRAN7 <= -1.00) THEN UCTRAN7 = .;
   IF (UCTRAN8 <= -1.00) THEN UCTRAN8 = .;
   IF (UCTRAN16 <= -1.00) THEN UCTRAN16 = .;
   IF (UCTRAN29 <= -1.00) THEN UCTRAN29 = .;
   IF (UCTRAN31 <= -1.00) THEN UCTRAN31 = .;
   IF (UCHIV22 <= -1.00) THEN UCHIV22 = .;
   IF (UCHIV23 <= -1.0) THEN UCHIV23 = .;
   IF (UCHIV28 <= -1.00) THEN UCHIV28 = .;
   IF (UCHIV7 <= -1.00) THEN UCHIV7 = .;
   IF (UCHM16 <= -1) THEN UCHM16 = .;
   IF (UCHM18 <= -1.00) THEN UCHM18 = .;
   IF (UCHM19 <= -1.00) THEN UCHM19 = .;
   IF (UCHOUS18 <= -1.00) THEN UCHOUS18 = .;
   IF (UCIASS2 <= -1.00) THEN UCIASS2 = .;
   IF (UCIASS31 <= -1.00) THEN UCIASS31 = .;
   IF (UCMDS4 <= -1.00) THEN UCMDS4 = .;
   IF (UCMDS7 <= -1.00) THEN UCMDS7 = .;
   IF (UCMDS24 <= -1.00) THEN UCMDS24 = .;
   IF (UCMDS25 <= -1.00) THEN UCMDS25 = .;
   IF (UCMDS26 <= -1.00) THEN UCMDS26 = .;
   IF (UCMDS31 <= -1.00) THEN UCMDS31 = .;
   IF (UCMES15 <= -1.00) THEN UCMES15 = .;
   IF (UCMES16 <= -1.00) THEN UCMES16 = .;
   IF (UCMES31 <= -1.00) THEN UCMES31 = .;
   IF (UCMHGC11 <= -1.00) THEN UCMHGC11 = .;
   IF (UCMHIC11 <= -1.00) THEN UCMHIC11 = .;
   IF (UCPEV7 <= -1.00) THEN UCPEV7 = .;
   IF (UCPSE13 <= -1.00) THEN UCPSE13 = .;
   IF (UCPSE14 <= -1.00) THEN UCPSE14 = .;
   IF (UCPSE15 <= -1.00) THEN UCPSE15 = .;
   IF (UCPSE16 <= -1.00) THEN UCPSE16 = .;
   IF (UCPSE31 <= -1.00) THEN UCPSE31 = .;
   IF (UCRMGT4 <= -1.00) THEN UCRMGT4 = .;
   IF (UCRMGT7 <= -1.00) THEN UCRMGT7 = .;
   IF (UCRMGT31 <= -1.00) THEN UCRMGT31 = .;
   IF (UCSAGC8 <= -1.00) THEN UCSAGC8 = .;
   IF (UCSAGC11 <= -1.00) THEN UCSAGC11 = .;
   IF (UCSAGC27 <= -1.00) THEN UCSAGC27 = .;
   IF (UCSAGC31 <= -1.00) THEN UCSAGC31 = .;
   IF (UCSAIC8 <= -1.00) THEN UCSAIC8 = .;
   IF (UCSAIC11 <= -1.00) THEN UCSAIC11 = .;
   IF (UCSAIC27 <= -1.00) THEN UCSAIC27 = .;
   IF (UCSAIC31 <= -1) THEN UCSAIC31 = .;
   IF (UCSTED7 <= -1.00) THEN UCSTED7 = .;
   IF (UCSTED16 <= -1.00) THEN UCSTED16 = .;
   IF (UCSTED17 <= -1.00) THEN UCSTED17 = .;
   IF (UCSTED31 <= -1.00) THEN UCSTED31 = .;
   IF (CSTPRCL <= -1.00) THEN CSTPRCL = .;
   IF (AVGAFT <= -1.00) THEN AVGAFT = .;
   IF (AVGCNET <= -1.00) THEN AVGCNET = .;
   IF (AVGCH <= -1.00) THEN AVGCH = .;
   IF (AVGCLED <= -1.00) THEN AVGCLED = .;
   IF (AVGTRAN <= -1.00) THEN AVGTRAN = .;
   IF (AVGHIV <= -1.00) THEN AVGHIV = .;
   IF (AVGHM <= -1.00) THEN AVGHM = .;
   IF (AVGHOUS <= -1.00) THEN AVGHOUS = .;
   IF (AVGIASS <= -1.00) THEN AVGIASS = .;
   IF (AVGMDS <= -1.00) THEN AVGMDS = .;
   IF (AVGMES <= -1.00) THEN AVGMES = .;
   IF (AVGMHGC <= -1.00) THEN AVGMHGC = .;
   IF (AVGMHIC <= -1.00) THEN AVGMHIC = .;
   IF (AVGPEVL <= -1.00) THEN AVGPEVL = .;
   IF (AVGPSE <= -1.00) THEN AVGPSE = .;
   IF (AVGRMGT <= -1.00) THEN AVGRMGT = .;
   IF (AVGSAGC <= -1.00) THEN AVGSAGC = .;
   IF (AVGSAIC <= -1.00) THEN AVGSAIC = .;
   IF (AVGSTED <= -1.00) THEN AVGSTED = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT SDUNUM sdunum. PROVIDER provider. SDUFOCUS sdufocus.
         SDUTYPE sdutype. FYEND fyend. NUMCLNT numclnt.
         TOTCOST totcost. TOTAFT totaft. TOTCNET totcnet.
         TOTCH totch. TOTCLED totcled. TOTTRAN tottran.
         TOTHIV tothiv. TOTHM tothm. TOTHOUS tothous.
         TOTIASS totiass. TOTMDS totmds. TOTMES totmes.
         TOTMHGC totmhgc. TOTMHIC totmhic. TOTPEVL totpevl.
         TOTPSE totpse. TOTRMGT totrmgt. TOTSAGC totsagc.
         TOTSAIC totsaic. TOTSTED totsted. UNAFT1 unaft1ff.
         UNAFT3 unaft3ff. UNAFT7 unaft7ff. UNAFT10 unaft10f.
         UNAFT12 unaft12f. UNCNET4 uncnet4f. UNCNET7 uncnet7f.
         UNCNET9 uncnet9f. UNCNET10 uncnet1f. UNCNET16 uncnet0f.
         UNCNET20 uncnet2f. UNCNET21 uncnet3f. UNCNET31 uncnet5f.
         UNCH5 unch5fff. UNCLED7 uncled7f. UNTRAN16 untran1f.
         UNTRAN29 untran2f. UNTRAN31 untran3f. UNTRAN7 untran7f.
         UNTRAN8 untran8f. UNHIV7 unhiv7ff. UNHIV22 unhiv22f.
         UNHIV23 unhiv23f. UNHIV28 unhiv28f. UNHM16 unhm16ff.
         UNHM18 unhm18ff. UNHM19 unhm19ff. UNHOUS18 unhous1f.
         UNIASS2 uniass2f. UNIASS31 uniass3f. UNMDS4 unmds4ff.
         UNMDS7 unmds7ff. UNMDS24 unmds24f. UNMDS25 unmds25f.
         UNMDS26 unmds26f. UNMDS31 unmds31f. UNMES15 unmes15f.
         UNMES16 unmes16f. UNMES31 unmes31f. UNMHGC8 unmhgc8f.
         UNMHGC11 unmhgc1f. UNMHIC8 unmhic8f. UNMHIC11 unmhic1f.
         UNPEV7 unpev7ff. UNPSE13 unpse13f. UNPSE14 unpse14f.
         UNPSE15 unpse15f. UNPSE16 unpse16f. UNPSE31 unpse31f.
         UNRMGT4 unrmgt4f. UNRMGT7 unrmgt7f. UNRMGT31 unrmgt3f.
         UNSAGC8 unsagc8f. UNSAGC11 unsagc1f. UNSAGC27 unsagc2f.
         UNSAGC31 unsagc3f. UNSAIC8 unsaic8f. UNSAIC11 unsaic1f.
         UNSAIC27 unsaic2f. UNSAIC31 unsaic3f. UNSTED7 unsted7f.
         UNSTED16 unsted1f. UNSTED17 unsted0f. UNSTED31 unsted3f.
         UCAFT1 ucaft1ff. UCAFT3 ucaft3ff. UCAFT7 ucaft7ff.
         UCAFT10 ucaft10f. UCAFT12 ucaft12f. UCCNET4 uccnet4f.
         UCCNET7 uccnet7f. UCCNET9 uccnet9f. UCCNET10 uccnet1f.
         UCCNET16 uccnet0f. UCCNET20 uccnet2f. UCCNET21 uccnet3f.
         UCCNET31 uccnet5f. UCCH5 ucch5fff. UCCLED7 uccled7f.
         UCTRAN7 uctran7f. UCTRAN8 uctran8f. UCTRAN16 uctran1f.
         UCTRAN29 uctran2f. UCTRAN31 uctran3f. UCHIV22 uchiv22f.
         UCHIV23 uchiv23f. UCHIV28 uchiv28f. UCHIV7 uchiv7ff.
         UCHM16 uchm16ff. UCHM18 uchm18ff. UCHM19 uchm19ff.
         UCHOUS18 uchous1f. UCIASS2 uciass2f. UCIASS31 uciass3f.
         UCMDS4 ucmds4ff. UCMDS7 ucmds7ff. UCMDS24 ucmds24f.
         UCMDS25 ucmds25f. UCMDS26 ucmds26f. UCMDS31 ucmds31f.
         UCMES15 ucmes15f. UCMES16 ucmes16f. UCMES31 ucmes31f.
         UCMHGC11 ucmhgc1f. UCMHIC11 ucmhic1f. UCPEV7 ucpev7ff.
         UCPSE13 ucpse13f. UCPSE14 ucpse14f. UCPSE15 ucpse15f.
         UCPSE16 ucpse16f. UCPSE31 ucpse31f. UCRMGT4 ucrmgt4f.
         UCRMGT7 ucrmgt7f. UCRMGT31 ucrmgt3f. UCSAGC8 ucsagc8f.
         UCSAGC11 ucsagc1f. UCSAGC27 ucsagc2f. UCSAGC31 ucsagc3f.
         UCSAIC8 ucsaic8f. UCSAIC11 ucsaic1f. UCSAIC27 ucsaic2f.
         UCSAIC31 ucsaic3f. UCSTED7 ucsted7f. UCSTED16 ucsted1f.
         UCSTED17 ucsted0f. UCSTED31 ucsted3f. CSTPRCL cstprcl.
         AVGAFT avgaft. AVGCNET avgcnet. AVGCH avgch.
         AVGCLED avgcled. AVGTRAN avgtran. AVGHIV avghiv.
         AVGHM avghm. AVGHOUS avghous. AVGIASS avgiass.
         AVGMDS avgmds. AVGMES avgmes. AVGMHGC avgmhgc.
         AVGMHIC avgmhic. AVGPEVL avgpevl. AVGPSE avgpse.
         AVGRMGT avgrmgt. AVGSAGC avgsagc. AVGSAIC avgsaic.
         AVGSTED avgsted.  ;
*/

RUN ;
